@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.001';     # TRIAL VERSION
+our $VERSION = '0.002';     # TRIAL VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -127,7 +127,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ Example:
 
     use DateTime;
     use DateTime::Format::XSD;
-    my ( $result_ref, $trace ) = $avatax->get_tax(
+    my ( $answer_ref, $trace ) = $avatax->get_tax(
         CustomerCode => 'ABC4335',
         DocDate      => DateTime::Format::XSD->format_datetime(
             DateTime->new( year => 2014, month => 1, day => 1 ) ),
@@ -181,20 +181,80 @@ Example:
 
 =head2 post_tax
 
+Example:
+
+    use DateTime;
+    use DateTime::Format::XSD;
+    my ( $answer_ref, $trace ) = $avatax->post_tax(
+        CompanyCode => 'APITrialCompany',
+        DocType     => 'SalesInvoice',
+        DocCode     => 'INV001',
+        Commit      => 0,
+        DocDate     => DateTime::Format::XSD->format_datetime(
+            DateTime->new(year => 2014, month => 1, day => 1) ),
+        TotalTax    => '14.27',
+        TotalAmount => 175,
+        NewDocCode  => 'INV001-1',
+    );
+
 =head2 commit_tax
 
+Example:
+
+    my ( $answer_ref, $trace ) = $avatax->commit_tax(
+        DocCode     => 'INV001',
+        DocType     => 'SalesInvoice',
+        CompanyCode => 'APITrialCompany',
+        NewDocCode  => 'INV001-1',
+    );
+
 =head2 cancel_tax
 
+Example:
+
+    my ( $answer_ref, $trace ) = $avatax->cancel_tax(
+        CompanyCode => 'APITrialCompany',
+        DocType     => 'SalesInvoice',
+        DocCode     => 'INV001',
+        CancelCode  => 'DocVoided',
+    );
+
 =head2 adjust_tax
 
 =head2 get_tax_history
 
+Example:
+
+    my ( $answer_ref, $trace ) = $avatax->get_tax_history(
+        CompanyCode => 'APITrialCompany',
+        DocType     => 'SalesInvoice',
+        DocCode     => 'INV001',
+        DetailLevel => 'Tax',
+    );
+
 =head2 is_authorized
 
+Example:
+
+    my ( $answer_ref, $trace ) = $avatax->is_authorized(
+        Operations => join ', ' => qw(
+            Ping
+            IsAuthorized
+            GetTax
+            PostTax
+            GetTaxHistory
+            CommitTax
+            CancelTax
+            AdjustTax
+        ),
+    );
+
 =head2 ping
 
+Example:
+
     use List::Util 1.33 'any';
-    my ( $result_ref, $trace ) = $avatax->ping;
+    my ( $answer_ref, $trace ) = $avatax->ping;
     for my $code ( $result_ref->{parameters}{PingResult}{ResultCode} ) {
         if ( $code eq 'Success' ) { say $code; last }
         if ( $code eq 'Warning' ) {
@@ -206,7 +266,11 @@ Example:
         }
     }
 
-=head2 validate
+=head2 reconcile_tax_history
+
+=head2 apply_payment
+
+=head2 tax_summary_fetch
 
 =head1 OTHER METHODS AND ATTRIBUTES
 
